@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI pitches for guitar chord voicings
 
-our $VERSION = '0.0108';
+our $VERSION = '0.0109';
 
 use strict;
 use warnings;
@@ -70,14 +70,11 @@ sub transform {
 sub _lowest_c {
     my ($pitches) = @_;
     my $lowest = 0;
-    if (any { $_ == 48 } @$pitches) {
-        $lowest = 48;
-    }
-    elsif (any { $_ == 60 } @$pitches) {
-        $lowest = 60;
-    }
-    elsif (any { $_ == 72 } @$pitches) {
-        $lowest = 72;
+    for my $pitch (48, 60, 72) {
+        if (any { $_ == $pitch } @$pitches) {
+            $lowest = $pitch;
+            last;
+        }
     }
     return $lowest;
 }
@@ -103,7 +100,7 @@ MIDI::Chord::Guitar - MIDI pitches for guitar chord voicings
 
 =head1 VERSION
 
-version 0.0108
+version 0.0109
 
 =head1 SYNOPSIS
 
@@ -125,7 +122,7 @@ of an C<E A D G B E> tuned guitar.
 
 =for html <p>Here is a handy diagram of ISO MIDI pitches laid out on a guitar neck:</p>
 <img src="https://raw.githubusercontent.com/ology/MIDI-Chord-Guitar/main/guitar-position-midi-octaves.png">
-<p>And here is a diagram of MIDI pitch numbers laid out on a guitar neck:</p>
+<p>And here is a companion diagram of MIDI pitch numbers laid out on a guitar neck:</p>
 <img src="https://raw.githubusercontent.com/ology/MIDI-Chord-Guitar/main/guitar-position-midi-numbers.png">
 
 =head1 ATTRIBUTES
@@ -199,6 +196,21 @@ The order of the voicing variations of a chord is by fret position.
 So, the first variations are at lower frets.  Please use the above
 diagrams to figure out the exact neck positions.
 
+Here is an example of the voicing CSV file which can be found with the
+B<as_file> method:
+
+  C,48,52,55,60,,
+  C,48,55,60,64,67,
+  C,48,52,55,60,64,72
+  C,48,55,60,64,67,72
+  C,60,67,72,76,,
+  C7,48,52,58,60,64,
+  C7,48,55,58,64,67,
+  C7,48,55,58,64,67,72
+  C7,48,52,55,60,64,70
+  C7,60,67,70,76,,
+  ...
+
 =head1 SEE ALSO
 
 The F<t/01-methods.t> and F<eg/autumn_leaves> files in this distribution
